==> angelspetrochem_0.5.11.zip: angelspetrochem_0.5.11/prototypes/items/petrochem-carbons.lua <==
data:extend(
{
--CARBON BASIC
	--GAS
{
    type = "fluid",
    name = "gas-methane",
    icon = "__angelspetrochem__/graphics/icons/gas-methane.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.3, g = 0.3, b = 0.3},
    flow_color = {r = 0.3, g = 0.3, b = 0.3},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethane",
    icon = "__angelspetrochem__/graphics/icons/gas-ethane.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.35, g = 0.35, b = 0.35},
    flow_color = {r = 0.35, g = 0.35, b = 0.35},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-butane",
    icon = "__angelspetrochem__/graphics/icons/gas-butane.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.4, g = 0.4, b = 0.4},
    flow_color = {r = 0.4, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-propene",
    icon = "__angelspetrochem__/graphics/icons/gas-propene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--OIL
{
    type = "fluid",
    name = "liquid-naphtha",
    icon = "__angelspetrochem__/graphics/icons/liquid-naphtha.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.4, b = 0.4},
    flow_color = {r = 0.8, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-mineral-oil",
    icon = "__angelspetrochem__/graphics/icons/liquid-mineral-oil.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.2, g = 0.6, b = 0.2},
    flow_color = {r = 0.2, g = 0.6, b = 0.2},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-fuel-oil",
    icon = "__angelspetrochem__/graphics/icons/liquid-fuel-oil.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.8, b = 0},
    flow_color = {r = 0.8, g = 0.8, b = 0},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--CRACKING
{
    type = "fluid",
    name = "gas-methanol",
    icon = "__angelspetrochem__/graphics/icons/gas-methanol.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.3, b = 0.3},
    flow_color = {r = 0.5, g = 0.3, b = 0.3},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethylene",
    icon = "__angelspetrochem__/graphics/icons/gas-ethylene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.45, g = 0.45, b = 0.45},
    flow_color = {r = 0.45, g = 0.45, b = 0.45},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-benzene",
    icon = "__angelspetrochem__/graphics/icons/gas-benzene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.5, b = 0.5},
    flow_color = {r = 0.5, g = 0.5, b = 0.5},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-synthesis",
    icon = "__angelspetrochem__/graphics/icons/gas-synthesis.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 1, g = 0.25, b = 1},
    flow_color = {r = 1, g = 0.25, b = 1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--CHEMICAL PROCESSING
	{
    type = "fluid",
    name = "liquid-toluene",
    icon = "__angelspetrochem__/graphics/icons/liquid-toluene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.15, g = 0.15, b = 0.15},
    flow_color = {r = 0.15, g = 0.15, b = 0.15},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-butadiene",
    icon = "__angelspetrochem__/graphics/icons/gas-butadiene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-phenol",
    icon = "__angelspetrochem__/graphics/icons/gas-phenol.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.7, g = 0.35, b = 0.35},
    flow_color = {r = 0.7, g = 0.35, b = 0.35},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethylbenzene",
    icon = "__angelspetrochem__/graphics/icons/gas-ethylbenzene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.55, g = 0.55, b = 0.55},
    flow_color = {r = 0.55, g = 0.55, b = 0.55},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-styrene",
    icon = "__angelspetrochem__/graphics/icons/gas-styrene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.6, g = 0.6, b = 0.6},
    flow_color = {r = 0.6, g = 0.6, b = 0.6},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-formaldehyde",
    icon = "__angelspetrochem__/graphics/icons/gas-formaldehyde.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.4, b = 0.4},
    flow_color = {r = 0.8, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-polyethylene",
    icon = "__angelspetrochem__/graphics/icons/gas-polyethylene.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.65, g = 0.65, b = 0.65},
    flow_color = {r = 0.65, g = 0.65, b = 0.65},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-glycerol",
    icon = "__angelspetrochem__/graphics/icons/gas-glycerol.png",
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.9, g = 0.45, b = 0.45},
    flow_color = {r = 0.9, g = 0.45, b = 0.45},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
}
)

==> angelspetrochem_0.7.6.zip: angelspetrochem_0.7.6/prototypes/items/petrochem-carbons.lua <==
data:extend(
{
--CARBON BASIC
	--GAS
{
    type = "fluid",
    name = "gas-methane",
    icon = "__angelspetrochem__/graphics/icons/gas-methane.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.3, g = 0.3, b = 0.3},
    flow_color = {r = 0.3, g = 0.3, b = 0.3},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethane",
    icon = "__angelspetrochem__/graphics/icons/gas-ethane.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.35, g = 0.35, b = 0.35},
    flow_color = {r = 0.35, g = 0.35, b = 0.35},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-butane",
    icon = "__angelspetrochem__/graphics/icons/gas-butane.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.4, g = 0.4, b = 0.4},
    flow_color = {r = 0.4, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-propene",
    icon = "__angelspetrochem__/graphics/icons/gas-propene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--OIL
{
    type = "fluid",
    name = "liquid-naphtha",
    icon = "__angelspetrochem__/graphics/icons/liquid-naphtha.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.4, b = 0.4},
    flow_color = {r = 0.8, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-mineral-oil",
    icon = "__angelspetrochem__/graphics/icons/liquid-mineral-oil.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.2, g = 0.6, b = 0.2},
    flow_color = {r = 0.2, g = 0.6, b = 0.2},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "liquid-fuel-oil",
    icon = "__angelspetrochem__/graphics/icons/liquid-fuel-oil.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.8, b = 0},
    flow_color = {r = 0.8, g = 0.8, b = 0},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--CRACKING
{
    type = "fluid",
    name = "gas-methanol",
    icon = "__angelspetrochem__/graphics/icons/gas-methanol.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.3, b = 0.3},
    flow_color = {r = 0.5, g = 0.3, b = 0.3},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethylene",
    icon = "__angelspetrochem__/graphics/icons/gas-ethylene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.45, g = 0.45, b = 0.45},
    flow_color = {r = 0.45, g = 0.45, b = 0.45},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-benzene",
    icon = "__angelspetrochem__/graphics/icons/gas-benzene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.5, g = 0.5, b = 0.5},
    flow_color = {r = 0.5, g = 0.5, b = 0.5},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-synthesis",
    icon = "__angelspetrochem__/graphics/icons/gas-synthesis.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {210/255, g = 120/255, b = 210/255},
    flow_color = {210/255, g = 120/255, b = 210/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
	--CHEMICAL PROCESSING
	{
    type = "fluid",
    name = "liquid-toluene",
    icon = "__angelspetrochem__/graphics/icons/liquid-toluene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.15, g = 0.15, b = 0.15},
    flow_color = {r = 0.15, g = 0.15, b = 0.15},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-butadiene",
    icon = "__angelspetrochem__/graphics/icons/gas-butadiene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-phenol",
    icon = "__angelspetrochem__/graphics/icons/gas-phenol.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.7, g = 0.35, b = 0.35},
    flow_color = {r = 0.7, g = 0.35, b = 0.35},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-ethylbenzene",
    icon = "__angelspetrochem__/graphics/icons/gas-ethylbenzene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.55, g = 0.55, b = 0.55},
    flow_color = {r = 0.55, g = 0.55, b = 0.55},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-styrene",
    icon = "__angelspetrochem__/graphics/icons/gas-styrene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.6, g = 0.6, b = 0.6},
    flow_color = {r = 0.6, g = 0.6, b = 0.6},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-formaldehyde",
    icon = "__angelspetrochem__/graphics/icons/gas-formaldehyde.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.8, g = 0.4, b = 0.4},
    flow_color = {r = 0.8, g = 0.4, b = 0.4},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-polyethylene",
    icon = "__angelspetrochem__/graphics/icons/gas-polyethylene.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.65, g = 0.65, b = 0.65},
    flow_color = {r = 0.65, g = 0.65, b = 0.65},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-glycerol",
    icon = "__angelspetrochem__/graphics/icons/gas-glycerol.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.9, g = 0.45, b = 0.45},
    flow_color = {r = 0.9, g = 0.45, b = 0.45},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-bisphenol-a",
    icon = "__angelspetrochem__/graphics/icons/gas-bisphenol-a.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 0.9, g = 0.7, b = 0.7},
    flow_color = {r = 0.9, g = 0.7, b = 0.7},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
{
    type = "fluid",
    name = "gas-acetone",
    icon = "__angelspetrochem__/graphics/icons/gas-acetone.png",
	icon_size = 32,
	default_temperature = 25,
    heat_capacity = "0.1KJ",
    base_color = {r = 1, g = 0.3, b = 0.3},
    flow_color = {r = 1, g = 0.3, b = 0.3},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
},
}
)
